@@ -58,8 +58,7 @@ def get_connection_object(conn):
     # PostgreSQL
     if (mode_ == "PostgreSQL"):
         if curs_ == "DICTIONARY":
-            print("lol")
-            return conn.cursor(cursor_factory=psycopg2.extras.DictCursor)
+            return conn.cursor(cursor_factory=psycopg2.extras.RealDictCursor)
         else:
             return conn.cursor()
     # MySQL (by Default)
